# coding: utf-8

"""
    

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class MemoryPageImage(BaseModel):
    """
    Metadata for one memory page-image rendition
    """ # noqa: E501
    memory_id: StrictStr = Field(description="Memory UUID", alias="memoryId")
    page_index: StrictInt = Field(description="0-based page index", alias="pageIndex")
    dpi: StrictInt = Field(description="Render DPI")
    content_type: StrictStr = Field(description="Image MIME type", alias="contentType")
    image_content_length: Optional[StrictInt] = Field(default=None, description="Image byte length", alias="imageContentLength")
    image_content_sha256: Optional[StrictStr] = Field(default=None, description="Hex-encoded SHA-256 digest of image content", alias="imageContentSha256")
    created_at: StrictInt = Field(description="Creation timestamp (milliseconds since epoch)", alias="createdAt")
    updated_at: StrictInt = Field(description="Last update timestamp (milliseconds since epoch)", alias="updatedAt")
    created_by_id: StrictStr = Field(description="Creator user UUID", alias="createdById")
    updated_by_id: StrictStr = Field(description="Last updater user UUID", alias="updatedById")
    __properties: ClassVar[List[str]] = ["memoryId", "pageIndex", "dpi", "contentType", "imageContentLength", "imageContentSha256", "createdAt", "updatedAt", "createdById", "updatedById"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MemoryPageImage from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if image_content_length (nullable) is None
        # and model_fields_set contains the field
        if self.image_content_length is None and "image_content_length" in self.model_fields_set:
            _dict['imageContentLength'] = None

        # set to None if image_content_sha256 (nullable) is None
        # and model_fields_set contains the field
        if self.image_content_sha256 is None and "image_content_sha256" in self.model_fields_set:
            _dict['imageContentSha256'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MemoryPageImage from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "memoryId": obj.get("memoryId"),
            "pageIndex": obj.get("pageIndex"),
            "dpi": obj.get("dpi"),
            "contentType": obj.get("contentType"),
            "imageContentLength": obj.get("imageContentLength"),
            "imageContentSha256": obj.get("imageContentSha256"),
            "createdAt": obj.get("createdAt"),
            "updatedAt": obj.get("updatedAt"),
            "createdById": obj.get("createdById"),
            "updatedById": obj.get("updatedById")
        })
        return _obj


