# coding: utf-8

"""
    

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from goodmem._generated.models.image_info import ImageInfo
from goodmem._generated.models.ocr_layout import OcrLayout
from goodmem._generated.models.page_timings import PageTimings
from typing import Optional, Set
from typing_extensions import Self

class OcrPage(BaseModel):
    """
    OCR output for a single page.
    """ # noqa: E501
    raw_json: Optional[StrictStr] = Field(default=None, description="Raw OCR JSON payload when requested", alias="rawJson")
    markdown: Optional[StrictStr] = Field(default=None, description="Markdown rendering when requested")
    layout: OcrLayout = Field(description="Parsed layout output")
    timings: PageTimings = Field(description="Timing breakdown for the page")
    image: ImageInfo = Field(description="Rendered image metadata")
    __properties: ClassVar[List[str]] = ["rawJson", "markdown", "layout", "timings", "image"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of OcrPage from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of layout
        if self.layout:
            _dict['layout'] = self.layout.to_dict()
        # override the default output from pydantic by calling `to_dict()` of timings
        if self.timings:
            _dict['timings'] = self.timings.to_dict()
        # override the default output from pydantic by calling `to_dict()` of image
        if self.image:
            _dict['image'] = self.image.to_dict()
        # set to None if raw_json (nullable) is None
        # and model_fields_set contains the field
        if self.raw_json is None and "raw_json" in self.model_fields_set:
            _dict['rawJson'] = None

        # set to None if markdown (nullable) is None
        # and model_fields_set contains the field
        if self.markdown is None and "markdown" in self.model_fields_set:
            _dict['markdown'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of OcrPage from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "rawJson": obj.get("rawJson"),
            "markdown": obj.get("markdown"),
            "layout": OcrLayout.from_dict(obj["layout"]) if obj.get("layout") is not None else None,
            "timings": PageTimings.from_dict(obj["timings"]) if obj.get("timings") is not None else None,
            "image": ImageInfo.from_dict(obj["image"]) if obj.get("image") is not None else None
        })
        return _obj


