# coding: utf-8

"""
    

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class LLMProviderType(str, Enum):
    """
    LLM provider types
    """

    """
    allowed enum values
    """
    OPENAI = 'OPENAI'
    LITELLM_PROXY = 'LITELLM_PROXY'
    OPEN_ROUTER = 'OPEN_ROUTER'
    VLLM = 'VLLM'
    OLLAMA = 'OLLAMA'
    LLAMA_CPP = 'LLAMA_CPP'
    CUSTOM_OPENAI_COMPATIBLE = 'CUSTOM_OPENAI_COMPATIBLE'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of LLMProviderType from a JSON string"""
        return cls(json.loads(json_str))


